Attribute VB_Name = "REGMODUL"
' --------------------------------------------------------
' This .BAS module contains functions for reading and
'   setting registry values in Windows 95 and Windows NT.
'   The demo is in the form of a functional registry editor,
'   although it is not meant to be a substitute for RegEdit
'   or RegEdt32.  Declares are not provided
'   for some rare registry functions, and not all functions
'   have demo usage implemented.  Only values of type REG_SZ
'   and REG_DWORD may be edited.
'
' Written 10/95 for VB4/32 by Don Bradner, modified 6/97 to
'   deal with VB5 incompatibilities.  Requirements to run include
'   VB5, Windows 95 or NT 3.51 or later, and Comctl32.OCX,
'   which comes with VB5 Pro or EE versions.
'
' This material is placed in the public domain.  No guarantees
'   are made, and no support is provided, but comments/bug
'   reports are welcome to Don Bradner at Compuserve 76130,1007
'   or at dbirdman@arcatapet.com.  Questions/comments are also
'   welcome in the 32-bit section of the Visual Basic Programmer's
'   Journal forum on Compuserve.
'
' Warning:  Editing registry values can seriously impact your
'   computer's operations.  You should only edit values when
'   you know what they should be.  If editing values as a
'   test, make a note of the original value and restore it
'   when you are done.
' --------------------------------------------------------

Option Explicit

' --------------------------------------------------------
' Data structure:
'   ISubclass
' --------------------------------------------------------

Public Type COPYDATASTRUCT
   dwData As Long
   cbData As Long
   lpData As Long
End Type

' --------------------------------------------------------
' FILETIME type is needed for RegEnumKey and
'   RegQueryInfoKey
' --------------------------------------------------------
Type FILETIME
    lLowDateTime    As Long
    lHighDateTime   As Long
End Type

' --------------------------------------------------------
' OsVersionInfo type is needed for GetVersionEx
' --------------------------------------------------------
Type OSVERSIONINFO
    dwVersionInfoSize As Long
    dwMajorVersion As Long
    dwMinorVersion As Long
    dwBuildNumber As Long
    dwPlatform As Long
    szCSDVersion As String * 128
End Type

Private Enum ESetWindowPosStyles
    SWP_SHOWWINDOW = &H40
    SWP_HIDEWINDOW = &H80
    SWP_FRAMECHANGED = &H20 ' The frame changed: send WM_NCCALCSIZE
    SWP_NOACTIVATE = &H10
    SWP_NOCOPYBITS = &H100
    SWP_NOMOVE = &H2
    SWP_NOOWNERZORDER = &H200 ' Don't do owner Z ordering
    SWP_NOREDRAW = &H8
    SWP_NOREPOSITION = SWP_NOOWNERZORDER
    SWP_NOSIZE = &H1
    SWP_NOZORDER = &H4
    SWP_DRAWFRAME = SWP_FRAMECHANGED
    HWND_NOTOPMOST = -2
End Enum


' Memory functions:
Declare Sub CopyMemory Lib "kernel32.dll" Alias "RtlMoveMemory" ( _
    lpvDest As Any, lpvSource As Any, ByVal cbCopy As Long)

' ************************************************
' Dlg init
' ************************************************

Public Counter As Integer
Public NamOp As String

Public Const flags = SWP_NOMOVE Or SWP_NOSIZE
Public Const conSwNormal = 1
Public Const HWND_TOPMOST = -1
Public Const WM_COPYDATA = &H4A

Declare Function SetWindowPos Lib "user32.dll" (ByVal hwnd As Long, ByVal hWndInsertAfter As Long, ByVal x As Long, ByVal y As Long, ByVal cX As Long, ByVal cY As Long, ByVal wFlags As Long) As Long
Declare Function SetWindowWord Lib "user32.dll" (ByVal hwnd As Long, ByVal nIndex As Long, ByVal nNewWord As Long) As Long
Declare Function DestroyWindow Lib "user32" (ByVal hwnd As Long) As Long
Declare Sub InitCommonControls Lib "comctl32" ()

' ************************************************


' ---------------------------
' 32-bit registry functions
' ---------------------------
Declare Function RegOpenKeyEx& Lib "advapi32.dll" Alias "RegOpenKeyExA" (ByVal hKey&, ByVal lpszSubKey$, dwOptions&, ByVal samDesired&, lpHKey&)
Declare Function RegCloseKey& Lib "advapi32.dll" (ByVal hKey&)
Declare Function RegQueryValueEx& Lib "advapi32.dll" Alias "RegQueryValueExA" (ByVal hKey&, ByVal lpszValueName$, ByVal lpdwRes&, lpdwType&, ByVal lpDataBuff$, nSize&)
Declare Function RegSetValueEx& Lib "advapi32.dll" Alias "RegSetValueExA" (ByVal hKey&, ByVal lpszValueName$, ByVal dwRes&, ByVal dwType&, lpDataBuff As Any, ByVal nSize&)
Declare Function RegConnectRegistry& Lib "advapi32.dll" (ByVal lpMachineName$, ByVal hKey&, phkResult&)
Declare Function RegCreateKeyEx& Lib "advapi32.dll" Alias "RegCreateKeyExA" (ByVal hKey&, ByVal lpSubKey$, ByVal Reserved&, ByVal lpClass$, ByVal dwOptions&, ByVal samDesired&, lpSecurityAttributes&, phkResult&, lpdwDisposition&)
Declare Function RegFlushKey& Lib "advapi32.dll" (ByVal hKey&)
Declare Function RegEnumKeyEx& Lib "advapi32.dll" Alias "RegEnumKeyExA" (ByVal hKey&, ByVal dwIndex&, ByVal lpname$, lpcbName&, ByVal lpReserved&, ByVal lpClass$, lpcbClass&, lpftLastWriteTime As FILETIME)

Declare Function RegEnumValue& Lib "advapi32.dll" Alias _
    "RegEnumValueA" (ByVal hKey&, ByVal dwIndex&, ByVal lpname$, _
    lpcbName&, ByVal lpReserved&, lpdwType&, lpValue As Any, lpcbValue&)

Declare Function RegQueryInfoKey& Lib "advapi32.dll" Alias "RegQueryInfoKeyA" (ByVal hKey&, ByVal lpClass$, lpcbClass&, ByVal lpReserved&, lpcSubKeys&, lpcbMaxSubKeyLen&, lpcbMaxClassLen&, lpcValues&, lpcbMaxValueNameLen&, lpcbMaxValueLen&, lpcbSecurityDescriptor&, lpftLastWriteTime As FILETIME)

Declare Function GetVersionEx& Lib "kernel32.dll" Alias "GetVersionExA" (lpStruct As OSVERSIONINFO)

' --------------------------------------------------------
' Functions used to show hourglass
' --------------------------------------------------------
Declare Function LoadCursor& Lib "user32.dll" Alias "LoadCursorA" (ByVal hInstance&, ByVal lpCursor&)
Declare Function SetCursor& Lib "user32.dll" (ByVal hCursor&)
Public Const IDC_WAIT = 32514&

Public iWaitCursor&

Public lNewKey& 'used to generate unique Node keys

' --------------------------------------------------------
' Return codes from Registration functions.
' --------------------------------------------------------
Const ERROR_SUCCESS = 0&
Const ERROR_BADDB = 1009&
Const ERROR_BADKEY = 1010&
Const ERROR_CANTOPEN = 1011&
Const ERROR_CANTREAD = 1012&
Const ERROR_CANTWRITE = 1013&
Const ERROR_OUTOFMEMORY = 14&
Const ERROR_INVALID_PARAMETER = 87&
Const ERROR_ACCESS_DENIED = 5&
Const ERROR_NO_MORE_ITEMS = 259&
Const ERROR_MORE_DATA = 234&

Public Const HKEY_CLASSES_ROOT = &H80000000
Public Const HKEY_CURRENT_USER = &H80000001
Public Const HKEY_LOCAL_MACHINE = &H80000002
Public Const HKEY_USERS = &H80000003
Public Const HKEY_PERFORMANCE_DATA = &H80000004
Public Const HKEY_CURRENT_CONFIG = &H80000005
Public Const HKEY_DYN_DATA = &H80000006
   
Public Const LB_SETHORIZONTALEXTENT = &H400 + 21

Const REG_NONE = 0&                        ' No value type
Public Const REG_SZ = 1&                   ' Unicode nul terminated string
Const REG_EXPAND_SZ = 2&                   ' Unicode nul terminated string
                                           ' (with environment variable references)
Const REG_BINARY = 3&                      ' Free form binary
Public Const REG_DWORD = 4&                ' 32-bit number
Const REG_DWORD_LITTLE_ENDIAN = 4&         ' 32-bit number (same as REG_DWORD)
Const REG_DWORD_BIG_ENDIAN = 5&            ' 32-bit number
Const REG_LINK = 6&                        ' Symbolic Link (unicode)
Const REG_MULTI_SZ = 7&                    ' Multiple Unicode strings
Const REG_RESOURCE_LIST = 8&               ' Resource list in the resource map
Const REG_FULL_RESOURCE_DESCRIPTOR = 9&    ' Resource list in the hardware description
Const REG_RESOURCE_REQUIREMENTS_LIST = 10&


' --------------------------------------------------------
' Read/Write permissions:
' --------------------------------------------------------
Const KEY_QUERY_VALUE = &H1&
Const KEY_SET_VALUE = &H2&
Const KEY_CREATE_SUB_KEY = &H4&
Const KEY_ENUMERATE_SUB_KEYS = &H8&
Const KEY_NOTIFY = &H10&
Const KEY_CREATE_LINK = &H20&
Const READ_CONTROL = &H20000
Const WRITE_DAC = &H40000
Const WRITE_OWNER = &H80000
Const SYNCHRONIZE = &H100000
Const STANDARD_RIGHTS_REQUIRED = &HF0000
Const STANDARD_RIGHTS_READ = READ_CONTROL
Const STANDARD_RIGHTS_WRITE = READ_CONTROL
Const STANDARD_RIGHTS_EXECUTE = READ_CONTROL
Const KEY_READ = STANDARD_RIGHTS_READ Or KEY_QUERY_VALUE Or KEY_ENUMERATE_SUB_KEYS Or KEY_NOTIFY
Const KEY_WRITE = STANDARD_RIGHTS_WRITE Or KEY_SET_VALUE Or KEY_CREATE_SUB_KEY
Const KEY_EXECUTE = KEY_READ


' --------------------------------------------------------
' Used with GetVersionEX
' --------------------------------------------------------
Public iWinVers%
Public Const WinNt = 1
Public Const Win32 = 2

Public Const VER_PLATFORM_WIN32_WINDOWS = 1
Public Const VER_PLATFORM_WIN32_NT = 2


' --------------------------------------------------------
' Public program variables
' --------------------------------------------------------
Public lTempLong&
Public fTempDbl#
Public sTempString$
Public nodetemp As node


' registry entry important stuff
Public rgeEntry$
Public rgeDataType&
Public rgeValue$
Public rgeMainKey&
Public rgeSubKey$

' --------------------------------------------------------
' Public program Kernel declarations
' --------------------------------------------------------

'
Declare Function WinExec Lib "kernel32.dll" (ByVal lpCmdLine As String, ByVal nCmdShow As Integer) As Integer
'Declare Function GetNumTasks Lib "kernel32.dll" () As Integer


'specifying the following parameters:

'lpCmdFile   \A string containing the name of the application to execute
'fuCmdShow   \An integer value that tells WinExec how to show the application
'            \when it is executed. This may be one of the following constants:

Public Const SW_HIDE = 0 '     \The window is hidden and activation passes to another window.
Public Const SW_MINIMIZE = 1 ' \The window is minimized and activation passes to another
'                              \window.
Public Const SW_RESTORE = 2 ' \The window is activated and displayed in its original size and
'                             \at its original location.
Public Const SW_SHOW = 3 ' \The window is activated and displayed in its current size and
'                          \at its current location.
Public Const SW_SHOWMAXIMIZED = 4 '   \The window is maximized and activated.
Public Const SW_SHOWMINIMIZED = 5 '   \The window is minimized and activated.
Public Const SW_SHOWMINNOACTIVE = 6 ' \The window is minimized but the active window is not
'                                     \changed.
Public Const SW_SHOWNA = 7 '  \The window is displayed at its current location in its current
'                             \size but the active window is not changed.
Public Const SW_SHOWNOACTIVATE = 8 ' \The window is displayed at its most recent location in
'                                    \its most recent size but the active window is not
'                                    \changed.
Public Const SW_SHOWNORMAL = 9 '   \The window is activated and displayed in its original
'                                  \size and at its original location.
'
'
' Error Code Description :
'   0 Out of memory
'   2 File Not found
'   3 Path Not found
'   5 Sharing/protection error
'   6 Each task requires separate data segments
'   10 Windows version Is incorrect
'   11 Not valid .EXE file
'   12 Cannot execute OS/2 application
'   13 Cannot execute DOS 4.0 application
'   14 EXE type is unknown
'   15 Protected memory mode not supported by Windows
'   16 Cannot load another instance of .EXE file
'   17 Cannot load second instance in large-frame EMS mode
'   18 Cannot load protected-mode application in real mode

'GDI Functions
'Blt mode
Public Const vbDstInvert = &H550009    ' Inversion de l'image destination bitmap
Public Const vbMergeCopy = &HC000CA   ' Combinaison du motif et de l'image source bitmap
Public Const vbMergePaint = &HBB0226  '  Combinaison de l'image source bitmap inverse et de l'image destination bitmap par un Ou logique (Or)
Public Const vbNotSrcCopy = &H330008  ' Copie de l'image source bitmap inverse vers la destination
Public Const vbNotSrcErase = &H1100A6 ' Inversion du rsultat de la combinaison des images bitmap destination et source par un Ou logique (Or)
Public Const vbPatCopy = -&HF00021   'Copie du motif vers l'image destination bitmap
Public Const vbPatInvert = -&H5A0049 ' Combinaison de l'image destination bitmap et du motif par un Ou exclusif (Xor)
Public Const vbPatPaint = -&HFB0A09  ' Combinaison de l'image source bitmap inverse et du motif par un Ou logique (Or). Combinaison du rsultat de cette opration avec l'image destination bitmap par un Ou logique (Or)
Public Const vbSrcAnd = &H8800C6     'Combinaison des pixels des images bitmap destination et source par un Et logique (And)
Public Const vbSrcCopy = &HCC0020    ' Copie de l'image bitmap source vers l'image bitmap destination
Public Const vbSrcErase = &H440328   ' Inversion de l'image bitmap destination et combinaison du rsultat avec l'image bitmap source par un Et logique (And)
Public Const vbSrcInvert = &H660046  ' Combinaison des pixels des images bitmap destination et source par un Ou exclusif (Xor)
Public Const vbSrcPaint = &HEE0086   ' Combinaison des pixels des images bitmap destination et source par un Ou logique (Or)

Const Pi = 3.14159265359
Public Declare Function SetPixel Lib "GDI32.dll" (ByVal hdc As Integer, ByVal x As Integer, ByVal y As Integer, ByVal crColor As Long) As Long
Public Declare Function GetPixel Lib "GDI32.dll" (ByVal hdc As Integer, ByVal x As Integer, ByVal y As Integer) As Long
Public Declare Function StretchBlt% Lib "GDI32.dll" (ByVal hdc%, ByVal x%, ByVal y%, ByVal nWidth%, ByVal nHeight%, ByVal hSrcDC%, ByVal xSrc%, ByVal ySrc%, ByVal nSrcWidth%, ByVal nSrcHeight%, ByVal dwRop&)

#If Win16 Then
Declare Function WritePrivateProfileString Lib "kernel32.dll" (ByVal AppName As String, ByVal KeyName As String, ByVal NewString As String, ByVal fileName As String) As Integer
Declare Function GetPrivateProfileString Lib "kernel32.dll" Alias "GetPrivateProfilestring" (ByVal AppName As String, ByVal KeyName As Any, ByVal default As String, ByVal ReturnedString As String, ByVal MaxSize As Integer, ByVal fileName As String) As Integer
#Else
Declare Function GetPrivateProfileString Lib "kernel32.dll" Alias "GetPrivateProfileStringA" (ByVal lpApplicationName As String, ByVal lpKeyName As String, ByVal lpDefault As String, ByVal lpReturnedString As String, ByVal nSize As Long, ByVal lpFileName As String) As Long
Declare Function WritePrivateProfileString Lib "kernel32.dll" Alias "WritePrivateProfileStringA" (ByVal lpApplicationName As String, ByVal lpKeyName As String, ByVal lpString As Any, ByVal lpFileName As String) As Long
#End If

Public Declare Function GetSystemDirectory Lib "kernel32.dll" Alias "GetSystemDirectoryA" (ByVal lpBuffer As String, ByVal nSize As Long) As Long
Private Declare Function GetTempPathA Lib "kernel32.dll" (ByVal nBufferLength As Long, ByVal lpBuffer As String) As Long

Public sysDir As String
Private Declare Function GetWindowsDirectory Lib "kernel32.dll" (ByVal lpBuffer As String, ByVal nSize As Long) As Long

' VB App_Path leek
Private Declare Function GetShortPathNameA Lib "kernel32.dll" (ByVal lpszLongPath As String, ByVal lpszShortPath As String, ByVal cchBuffer As Long) As Long
Private Declare Function GetLongPathNameA Lib "kernel32.dll" (ByVal lpszShortPath As String, ByVal lpszLongPath As String, ByVal cchBuffer As Long) As Long


' **************************************************************
' Classe Dlg setting
' **************************************************************

Public OpenDialog As New clsCDEx


Private Declare Function GetWindowLong Lib "user32.dll" Alias "GetWindowLongA" (ByVal hwnd As Long, ByVal nIndex As Long) As Long
Private Declare Function SetWindowLong Lib "user32.dll" Alias "SetWindowLongA" (ByVal hwnd As Long, ByVal nIndex As Long, ByVal dwNewLong As Long) As Long
Private Const GWL_EXSTYLE = (-20)
Private Const WS_EX_WINDOWEDGE = &H100
Private Const WS_EX_CLIENTEDGE = &H200
Private Const WS_EX_STATICEDGE = &H20000

Private Declare Function ShellExecute Lib "shell32.dll" Alias "ShellExecuteA" (ByVal hwnd As Long, ByVal lpOperation As String, ByVal lpFile As String, ByVal lpParameters As String, ByVal lpDirectory As String, ByVal nShowCmd As Long) As Long
Private Declare Function ShellExecuteForExplore Lib "shell32.dll" Alias "ShellExecuteA" (ByVal hwnd As Long, ByVal lpOperation As String, ByVal lpFile As String, lpParameters As Any, lpDirectory As Any, ByVal nShowCmd As Long) As Long

Public Enum EShellShowConstants
    essSW_HIDE = 0
    essSW_MAXIMIZE = 3
    essSW_MINIMIZE = 6
    essSW_SHOWMAXIMIZED = 3
    essSW_SHOWMINIMIZED = 2
    essSW_SHOWNORMAL = 1
    essSW_SHOWNOACTIVATE = 4
    essSW_SHOWNA = 8
    essSW_SHOWMINNOACTIVE = 7
    essSW_SHOWDEFAULT = 10
    essSW_RESTORE = 9
    essSW_SHOW = 5
End Enum

Private Const ERROR_FILE_NOT_FOUND = 2&
Private Const ERROR_PATH_NOT_FOUND = 3&
Private Const ERROR_BAD_FORMAT = 11&
Private Const SE_ERR_ACCESSDENIED = 5        ' access denied
Private Const SE_ERR_ASSOCINCOMPLETE = 27
Private Const SE_ERR_DDEBUSY = 30
Private Const SE_ERR_DDEFAIL = 29
Private Const SE_ERR_DDETIMEOUT = 28
Private Const SE_ERR_DLLNOTFOUND = 32
Private Const SE_ERR_FNF = 2                ' file not found
Private Const SE_ERR_NOASSOC = 31
Private Const SE_ERR_PNF = 3                ' path not found
Private Const SE_ERR_OOM = 8                ' out of memory
Private Const SE_ERR_SHARE = 26

Private Const MAX_PATH = 260

Private Declare Function GetShortPathName Lib "kernel32.dll" Alias "GetShortPathNameA" (ByVal lpszLongPath As String, ByVal lpszShortPath As String, ByVal cchBuffer As Long) As Long

Private Type WIN32_FIND_DATA
   dwFileAttributes As Long
   ftCreationTime As FILETIME
   ftLastAccessTime As FILETIME
   ftLastWriteTime As FILETIME
   nFileSizeHigh As Long
   nFileSizeLow As Long
   dwReserved0 As Long
   dwReserved1 As Long
   cFileName As String * MAX_PATH
   cAlternate As String * 14
End Type
Private Declare Function FindFirstFile Lib "kernel32.dll" Alias "FindFirstFileA" (ByVal lpFileName As String, lpFindFileData As WIN32_FIND_DATA) As Long
Private Declare Function FindClose Lib "kernel32.dll" (ByVal hFindFile As Long) As Long
Private Declare Function lopen Lib "kernel32.dll" Alias "_lopen" (ByVal lpPathName As String, ByVal iReadWrite As Long) As Long
Private Declare Function lclose Lib "kernel32.dll" Alias "_lclose" (ByVal hFile As Long) As Long
Private Declare Function SetFileTime Lib "kernel32.dll" (ByVal hFile As Long, lpCreationTime As FILETIME, lpLastAccessTime As FILETIME, lpLastWriteTime As FILETIME) As Long
Private Declare Function SetFileAttributes Lib "kernel32.dll" Alias "SetFileAttributesA" (ByVal lpFileName As String, ByVal dwFileAttributes As Long) As Long
Private Const OF_WRITE = &H1
Private Const OF_SHARE_DENY_WRITE = &H20
Private Const GENERIC_WRITE = &H40000000
Private Const GENERIC_READ = &H80000000
Private Const FILE_SHARE_WRITE = &H2
Private Const CREATE_ALWAYS = 2
Private Const FILE_BEGIN = 0
Private Const SECTION_MAP_WRITE = &H2



Public Function FileExists(fileName As String) As Boolean
If fileName = "" Then FileExists = False: Exit Function
Dim long_file As String
long_file = fileName 'GetLongPathName(FileName)

    On Error GoTo errhandle

' If GetAttr(FileName) And vbDirectory =16 -> directory name !
    If (GetAttr(fileName) And vbDirectory) = vbDirectory Then
            FileExists = True: Exit Function
    Else
' If filename !
    If Dir(long_file) = Cut_Name(fileName) Then FileExists = True: Exit Function
    If Dir(long_file) <> "" Then FileExists = True Else FileExists = False
End If
errhandle:
FileExists = False
End Function



Function truncatepath$(TPath$, TForm As Form, TControl As Control)
Dim FirstSlash%
    On Error GoTo TPathError
    TPath = Trim(TPath): ' "H" in string = ???
    FirstSlash = InStr(3, TPath, "\")
    Do Until TForm.TextWidth(TPath) <= TControl.Width
        lTempLong = InStr(FirstSlash + 5, TPath, "\")
        TPath = left$(TPath, FirstSlash) & "..." & Mid$(TPath, lTempLong, Len(TPath) - lTempLong + 1)
    Loop
TooLong:
On Error GoTo StillError
If TForm.TextWidth(TPath) > TControl.Width Then
    Do Until TForm.TextWidth(TPath) <= TControl.Width
        TPath = left$(TPath, Len(TPath) - 1)
    Loop
    TPath = left$(TPath, Len(TPath) - 3) & "..."
End If
FinishAnyWay:
    truncatepath = TPath
    Exit Function
TPathError:
    Resume TooLong
StillError:
    Resume FinishAnyWay
End Function


Function WordLo(lLongIn&) As Integer
    If (lLongIn And &HFFFF&) > &H7FFF Then
        WordLo = (lLongIn And &HFFFF&) - &H10000
    Else
        WordLo = lLongIn And &HFFFF&
    End If
End Function

' Internal function cut attributes "disk.dsk" = "disk"
Public Function Cut_attr(char As String) As String
For cmp = Len(char) To 1 Step -1
If Mid(char, cmp, 1) = "." Then Cut_attr = Mid(char, 1, cmp - 1): Exit For
If Mid(char, cmp, 1) = "\" Then Cut_attr = char: Exit For
Next cmp
End Function

Public Function Cut_Path_Name(Long_name_file As String) As String
Dim LastSlash, scan_path As Integer
Dim char_path As String * 1
If Long_name_file = "" Then Cut_Path_Name = "": Exit Function
    scan_path = Len(Long_name_file)
    
Do While scan_path <> 1
    char_path = Mid(Long_name_file, scan_path, 1)
    If InStr(char_path, "\") <> 0 Then LastSlash = scan_path: Exit Do
    scan_path = scan_path - 1
Loop
Cut_Path_Name = left(Long_name_file, LastSlash - 1)
End Function
Public Function Cut_Name(ByRef Ln_file As String) As String
Dim LastSlash, scan_path As Integer
Dim char_path As String * 1
Dim lng_file As String
lng_file = GetLongPathName(Ln_file)
Ln_file = lng_file

'If Ln_file = "" Then Cut_Name = "": Exit Function
If InStr(Ln_file, "\") = 0 Then Cut_Name = Ln_file: Exit Function
   
    scan_path = Len(Ln_file)
    Do While InStr(1, Mid(Ln_file, scan_path, 1), "\", vbBinaryCompare) = 0
     scan_path = scan_path - 1
    Loop
 LastSlash = scan_path
Cut_Name = Trim(Right(Ln_file, Len(Ln_file) - LastSlash))

End Function
'  copy *.* c:\??? (x NumFiles)
Sub CopyFile(SrcDir As String, TrgtDir As String, NumFiles As Integer)
    Dim OldDir As String  'source dir name
    Dim NewDir As String 'target dir name
    Dim fileName As String 'source filename
    Dim sType As String 'file type (extension)

    OldDir = SrcDir
    If Right$(OldDir, 1) <> "\" Then
        OldDir = OldDir & "\"
    End If

    NewDir = TrgtDir
    If Right$(NewDir, 1) <> "\" Then
        NewDir = NewDir & "\"
    End If

    NumFiles = 0      'returns # files copied

    fileName = Dir$(OldDir & "*.*")
    While fileName <> ""
        On Error Resume Next
            FileCopy (OldDir & fileName), (NewDir & fileName)
            If err = 0 Then
                NumFiles = NumFiles + 1
            Else
                Beep
                MsgBox Error$, vbExclamation, ("Error copying file " _
                                                    & fileName)
            End If
        On Error GoTo 0

        fileName = Dir$        'get next matching file

        DoEvents            'allow processes to occur
    Wend
End Sub
'
'  Returns the system directory.
'
Public Function GetSystemDir() As String
   Dim s As String
   Dim i As Integer
   i = GetSystemDirectory("", 0)
   s = Space(i)
   Call GetSystemDirectory(s, i)
   GetSystemDir = AddBackslash(left$(s, i - 1))
End Function

'
'  Returns the Temp directory.
'
Public Function GetTmpDir() As String
   Dim s As String
   Dim i As Integer
   i = GetTempPathA(0, "")
   s = Space(i)
   Call GetTempPathA(i, s)
   GetTmpDir = AddBackslash(left$(s, i - 1))
End Function

'
'  Returns the windows directory.
'
Public Function GetWindowsDir() As String
   Dim s As String
   Dim i As Integer
   i = GetWindowsDirectory("", 0)
   s = Space(i)
   Call GetWindowsDirectory(s, i)
   GetWindowsDir = AddBackslash(left$(s, i - 1))
End Function
'
'  Adds a backslash if the string doesn't have one already.
'
Public Function AddBackslash(s As String) As String
   If Len(s) > 0 Then
      If Right$(s, 1) <> "\" Then
         AddBackslash = s + "\"
      Else
         AddBackslash = s
      End If
   Else
      AddBackslash = "\"
   End If
End Function

 
 Public Function Get_Short_Path_Name(longpath As String) As String
   Dim s As String
   Dim i As Long
   
   i = Len(longpath) + 1
   s = String(i, 0)
   GetShortPathName longpath, s, i
   
   Get_Short_Path_Name = left$(s, InStr(s, Chr$(0)) - 1)
End Function

Public Function GetLongPathName(Shortpath As String) As String
   Dim s As String
   Dim i As Long
   
   i = 255
   s = String(i, 0)
   GetLongPathNameA Shortpath, s, i
   
   GetLongPathName = left$(s, InStr(s, Chr$(0)) - 1)
End Function

Public Function GetFileAttrib(File As String) As String
Dim strc As Integer
Dim dotT As Boolean
If File = "" Then Exit Function
' Get 3 attribut char.
' Ex.: "file.cpcn" ->'-"PCN"
' "file."->""

strc = Len(File)
dotT = False

Do Until Mid(File, strc, 1) = "\"
If Mid(File, strc, 1) = "." Then dotT = True: Exit Do
strc = strc - 1
Loop

If dotT = False Then GetFileAttrib = "": Exit Function ' No dot found!
If Len(File) - strc > 0 Then GetFileAttrib = Right(File, Len(File) - strc) Else GetFileAttrib = "": Exit Function 'Empty!
If Len(GetFileAttrib) > 3 Then GetFileAttrib = Trim(UCase(Right(File, 3))) Else GetFileAttrib = Trim(UCase(GetFileAttrib))

End Function

Public Function GetTxtFile(File As String, Optional Tag As Boolean = False, Optional Put_It_to As Object = Nothing) As String

Dim scanfile, fileName As String
Dim scanTMP As String


LiX = FreeFile

If Tag = True Then fileName = App_Path & "\" & Tag_Path & "\" & File Else fileName = File
If FileExists(fileName) = False Then Exit Function
Open fileName For Input Access Read As #LiX
  
   Do While Not EOF(LiX)
       Input #LiX, scanfile
       scanTMP = scanTMP & Chr(13) & Chr(10) & scanfile
   Loop
Close #LiX

GetTxtFile = scanTMP

If Not Put_It_to Is Nothing Then
Put_It_to.text = scanTMP
End If

End Function

Public Function PutTxtFile(File As String, Optional Text_Var As String = "", Optional Tag As Boolean = False, Optional Put_It_to As Object = Nothing) As String


Dim scanfile, fileName As String
Dim scanTMP As String



If Not Put_It_to Is Nothing Then
Text_Var = Put_It_to.text
End If

If Text_Var = "" And Put_It_to Is Nothing Then
scanTMP = "Empty text..."
PutTxtFile = "Empty text..."
Else
scanTMP = Text_Var
End If

If Tag = True Then fileName = App_Path & "\" & Tag_Path & "\" & File Else fileName = File

If scanTMP = "" Then Exit Function

LiX = FreeFile
Open fileName For Output Access Write As #LiX Len = Len(scanTMP)

Print #LiX, scanTMP

Close #LiX

PutTxtFile = "File saved."

End Function

Public Function Get_short_dir_name(Long_name_file As String) As String
Dim Lastdot, scan_path As Integer
Dim char_path As String * 1
If Long_name_file = "" Then Get_short_dir_name = "": Exit Function
    scan_path = Len(Long_name_file)
    
Do While scan_path <> 1
    char_path = Mid(Long_name_file, scan_path, 1)
    If InStr(char_path, ".") <> 0 Then Lastdot = scan_path: Exit Do
    scan_path = scan_path - 1
Loop
Get_short_dir_name = left(Long_name_file, Lastdot - 1)

End Function
Public Sub pShell(ByVal sWhat As String)
   On Error Resume Next
   ShellEx sWhat, , , , , 0 'Me.hwnd
   If (err.number <> 0) Then
       MsgBox "Sorry, I failed to open '" & sWhat & "' due to an error." & vbCrLf & vbCrLf & "[" & err.description & "]", vbExclamation
   End If
End Sub
Public Function ShellEx( _
        ByVal sFile As String, _
        Optional ByVal eShowCmd As EShellShowConstants = essSW_SHOWDEFAULT, _
        Optional ByVal sParameters As String = "", _
        Optional ByVal sDefaultDir As String = "", _
        Optional sOperation As String = "open", _
        Optional Owner As Long = 0 _
    ) As Boolean
Dim lR As Long
Dim lErr As Long, sErr As Long
    If (InStr(UCase$(sFile), ".EXE") <> 0) Then
        eShowCmd = 0
    End If
    On Error Resume Next
    If (sParameters = "") And (sDefaultDir = "") Then
        lR = ShellExecuteForExplore(Owner, sOperation, sFile, 0, 0, essSW_SHOWNORMAL)
    Else
        lR = ShellExecute(Owner, sOperation, sFile, sParameters, sDefaultDir, eShowCmd)
    End If
    If (lR < 0) Or (lR > 32) Then
        ShellEx = True
    Else
        ' raise an appropriate error:
        lErr = vbObjectError + 1048 + lR
        Select Case lR
        Case 0
            lErr = 7: sErr = "Out of memory"
        Case ERROR_FILE_NOT_FOUND
            lErr = 53: sErr = "File not found"
        Case ERROR_PATH_NOT_FOUND
            lErr = 76: sErr = "Path not found"
        Case ERROR_BAD_FORMAT
            sErr = "The executable file is invalid or corrupt"
        Case SE_ERR_ACCESSDENIED
            lErr = 75: sErr = "Path/file access error"
        Case SE_ERR_ASSOCINCOMPLETE
            sErr = "This file type does not have a valid file association."
        Case SE_ERR_DDEBUSY
            lErr = 285: sErr = "The file could not be opened because the target application is busy. Please try again in a moment."
        Case SE_ERR_DDEFAIL
            lErr = 285: sErr = "The file could not be opened because the DDE transaction failed. Please try again in a moment."
        Case SE_ERR_DDETIMEOUT
            lErr = 286: sErr = "The file could not be opened due to time out. Please try again in a moment."
        Case SE_ERR_DLLNOTFOUND
            lErr = 48: sErr = "The specified dynamic-link library was not found."
        Case SE_ERR_FNF
            lErr = 53: sErr = "File not found"
        Case SE_ERR_NOASSOC
            sErr = "No application is associated with this file type."
        Case SE_ERR_OOM
            lErr = 7: sErr = "Out of memory"
        Case SE_ERR_PNF
            lErr = 76: sErr = "Path not found"
        Case SE_ERR_SHARE
            lErr = 75: sErr = "A sharing violation occurred."
        Case Else
            sErr = "An error occurred occurred whilst trying to open or print the selected file."
        End Select
                
        err.Raise lErr, , App.EXEName & ".GShell", sErr
        ShellEx = False
    End If

End Function
Public Function SPChar(number As Integer, char As String) As String

Dim a As Integer
a = 0
TmpChar = ""

Do While a < number
    TmpChar = TmpChar + char: a = a + 1
Loop

SPChar = TmpChar
End Function


Sub FadeIn(Lab As Label)
Lab.ForeColor = &HC0C0C0
Timeout (0.1)
Lab.ForeColor = &H808080
Timeout (0.1)
Lab.ForeColor = &H0&
End Sub

Sub FadeOut(Lab As Label)
Lab.ForeColor = &H0&
Timeout (0.1)
Lab.ForeColor = &H808080
Timeout (0.1)
Lab.ForeColor = &HC0C0C0
End Sub

Sub Show_error()
 Beep
 MsgBox Error$, vbExclamation, err.description
End Sub
